============================
pybullet_planning
============================

.. start-badges

.. image:: https://readthedocs.org/projects/pybullet-planning/badge/?version=latest
    :target: https://pybullet-planning.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status


.. image:: https://travis-ci.com/yijiangh/pybullet_planning.svg?branch=dev
    :target: https://travis-ci.com/yijiangh/pybullet_planning
    :alt: Travis CI


.. image:: https://coveralls.io/repos/github/yijiangh/pybullet_planning/badge.svg?branch=dev
    :target: https://coveralls.io/github/yijiangh/pybullet_planning?branch=dev
    :alt: Coveralls


.. image:: https://img.shields.io/badge/License-MIT-blue.svg
    :target: https://github.com/yijiangh/pybullet_planning/blob/dev/LICENSE
    :alt: License MIT

.. end-badges

.. Write project description

**pybullet_planning** is a suite of utility functions to facilitate robotic planning related research on the
`pybullet <https://github.com/bulletphysics/bullet3>`_ physics simulation engine.


========
Contents
========

.. toctree::
   :maxdepth: 3
   :titlesonly:

   readme
   reference
   contributing
   authors
   changelog
